pub unsafe extern "C" fn om_variable_get_chunks(
variable: *const OmVariable_t,
) -> *const u64Expand description
Get a pointer to the chunk dimensions of an OM Variable
pub unsafe extern "C" fn om_variable_get_chunks(
variable: *const OmVariable_t,
) -> *const u64Get a pointer to the chunk dimensions of an OM Variable