pub unsafe extern "C" fn om_variable_get_dimensions(
variable: *const OmVariable_t,
) -> *const u64Expand description
Get a pointer to the dimensions of a OM variable
pub unsafe extern "C" fn om_variable_get_dimensions(
variable: *const OmVariable_t,
) -> *const u64Get a pointer to the dimensions of a OM variable